@@ -259,7 +259,11 @@ class GRPCIndex(GRPCIndexBase):
             return self._wrap_grpc_call(self.stub.Upsert, request, timeout=timeout)
 
     def delete(self, *args, async_req=False, **kwargs):
-        request = DeleteRequest(*args, **kwargs)
+        _filter = dict_to_proto_struct(kwargs.pop('filter', None))
+        filter_param = {}
+        if _filter:
+            filter_param['filter'] = _filter
+        request = DeleteRequest(*args, **kwargs, **filter_param)
         timeout = kwargs.pop('timeout', None)
         if async_req:
             future = self._wrap_grpc_call(self.stub.Delete.future, request, timeout=timeout)
